@@ -19,10 +19,14 @@ else:
     raise RuntimeError("Can't find imagemagick dll")
 
 lib.MagickCoreGenesis(None, False)
+lib.SetMagickMemoryMethods(
+    ctypes.pythonapi.PyMem_Malloc,
+    ctypes.pythonapi.PyMem_Realloc,
+    ctypes.pythonapi.PyMem_Free)
 
 atexit.register(lib.MagickCoreTerminus)
 
-from image import *
-from types import *
-from enums import *
-from animation import *
+from .image import *
+from .types import *
+from .enums import *
+from .animation import *
